aboutsummaryrefslogtreecommitdiffstats
path: root/components/layout/lib.rs
diff options
context:
space:
mode:
authorMichael Partheil <michael.partheil@gmail.com>2017-07-18 18:48:57 +0200
committerMichael Partheil <michael.partheil@gmail.com>2017-07-19 09:29:05 +0200
commitb07ebbae6b92bc510a6ddbf24676498f86bf5a8a (patch)
treed2eab40052ec2062ae19bd4163feec66f43aa112 /components/layout/lib.rs
parentd403f404382c66485d9744787ce021556be59d6c (diff)
downloadservo-b07ebbae6b92bc510a6ddbf24676498f86bf5a8a.tar.gz
servo-b07ebbae6b92bc510a6ddbf24676498f86bf5a8a.zip
Replace all uses of the style::stylearc alias with servo_arc.
The alias is left there temporarilly and will be removed completely in a later commit where also components/style/gecko/generated/structs_{debug|release}.rs are re-generated (they still use the old alias).
Diffstat (limited to 'components/layout/lib.rs')
-rw-r--r--components/layout/lib.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/components/layout/lib.rs b/components/layout/lib.rs
index 3527c3590cd..9b6e27311cf 100644
--- a/components/layout/lib.rs
+++ b/components/layout/lib.rs
@@ -36,6 +36,7 @@ extern crate script_layout_interface;
extern crate script_traits;
#[macro_use] extern crate serde;
extern crate serde_json;
+extern crate servo_arc;
extern crate servo_atoms;
extern crate servo_config;
extern crate servo_geometry;
@@ -91,6 +92,6 @@ pub use fragment::Fragment;
pub use fragment::SpecificFragmentInfo;
pub use self::data::LayoutData;
// We can't use stylearc for everything in layout, because the Flow stuff uses
// weak references.
-use style::stylearc::Arc as StyleArc;
+use servo_arc::Arc as ServoArc;
@@ -91,6 +92,6 @@ pub use fragment::Fragment;
pub use fragment::SpecificFragmentInfo;
pub use self::data::LayoutData;
-// We can't use stylearc for everything in layout, because the Flow stuff uses
+// We can't use servo_arc for everything in layout, because the Flow stuff uses
// weak references.